@@ -9,7 +9,7 @@ seqdss <- function(seqdata, with.missing=FALSE) {
 
 	nbseq <- nrow(seqdata)
 
-	sl <- seqlength(seqdata) 
+	sl <- seqlength(seqdata, with.missing=TRUE)
 	maxsl <- max(sl)
 
 	void <- attr(seqdata, "void")
@@ -27,7 +27,7 @@ seqdss <- function(seqdata, with.missing=FALSE) {
 	if (!with.missing)
 		seqdatanum[is.na(seqdatanum)] <- -99
 
-	maxcol <- 0 
+	maxcol <- 0
 	for (i in 1:nbseq) {
 		idx <- 1
 		j <- 1
@@ -37,11 +37,11 @@ seqdss <- function(seqdata, with.missing=FALSE) {
 		while (idx <= sl[i]) {
 			iseq <- tmpseq[idx]
 
-			while (idx < sl[i] & (tmpseq[idx+1]==iseq || tmpseq[idx+1]==-99)) { 
+			while (idx < sl[i] & (tmpseq[idx+1]==iseq || tmpseq[idx+1]==-99)) {
 				idx <- idx+1
 			}
 
-			## The range of the numeric alphabet 
+			## The range of the numeric alphabet
 			## obtained with seqasnum is 0..n
 			if (iseq!=-99) {
 				trans[i,j] <- statl[(iseq+1)]
@@ -67,4 +67,3 @@ seqdss <- function(seqdata, with.missing=FALSE) {
 
 	return(trans)
 }
-
