@@ -2,6 +2,6 @@
 ## PLOT OF THE SEQUENCE OF MODAL STATES
 ## ====================================
 
-seqmsplot <- function(seqdata, group = NULL, main = NULL, ...) {
+seqmsplot <- function(seqdata, group = NULL, main = "auto", ...) {
 	seqplot(seqdata, group=group, type="ms", main=main, ...)
 }
