@@ -1,12 +1,12 @@
 ## RECHERCHE DE SOUS-SEQUENCES
 
-seqpm <- function(seqdata, pattern) {
+seqpm <- function(seqdata, pattern, sep="") {
 
 	if (!inherits(seqdata,"stslist")) {
 		stop("data is not a sequence object, use 'seqdef' function to create one")
 	}
 
-	seqdata <- seqconc(seqdata,sep="")
+	seqdata <- seqconc(seqdata,sep=sep)
 
 	pm <- grep(pattern,seqdata)
 	nbocc <- length(pm)
